@@ -1,24 +1,9 @@
 from __future__ import annotations
 
-import asyncio
-import random
-from asyncio import (
-    CancelledError,
-    Event,
-    Future,
-    LifoQueue,
-    PriorityQueue,
-    Queue,
-    QueueEmpty,
-    shield,
-    Task,
-)
-from functools import cached_property
+from asyncio import Future, LifoQueue, PriorityQueue, Queue, QueueEmpty, Task
 from typing import *
 
-import math
-
-from .event_like import Fuse
+from astream.event_like import Fuse
 
 _T = TypeVar("_T")
 
@@ -40,6 +25,7 @@ class QueueExhausted(QueueEmpty):
     yield any more items.
     """
 
+
 class CloseableQueue(Queue[_T]):
     def __init__(self, maxsize: int = 0) -> None:
         super().__init__(maxsize=maxsize)
@@ -229,3 +215,12 @@ if __name__ == "__main__":
         # q.get_nowait()
 
     asyncio.run(main(), debug=True)
+__all__ = (
+    "CloseableLifoQueue",
+    "CloseablePriorityQueue",
+    "CloseableQueue",
+    "empty_gen",
+    "feed_queue",
+    "QueueClosed",
+    "QueueExhausted",
+)
