@@ -1,7 +1,6 @@
 from __future__ import annotations
 
 import asyncio
-import inspect
 from functools import wraps
 from types import NotImplementedType
 from typing import *
@@ -286,10 +285,6 @@ async def _consume(async_iterable: AsyncIterable[Any]) -> None:
         pass
 
 
-_StreamT = TypeVar("_StreamT", bound="Stream[Any]")
-_StreamTA: TypeAlias = Type["Stream[_T]"]
-
-
 class Stream(AsyncIterator[_T]):
     def __init__(self, src: AsyncIterable[_T] | Iterable[_T]) -> None:
         self._src: AsyncIterator[_T] = ensure_async_iterator(src)
@@ -544,19 +539,35 @@ class Sink(FnTransformer[_I, _O]):
     ...
 
 
-def sink(
-    _fn: Callable[Concatenate[AsyncIterator[_A], _P], Coroutine[object, object, _B]]
-) -> Callable[_P, Sink[_A, _B]]:
-    print(f"sink {_fn=}")
+class _SinkFnWrapper(Generic[_P, _A, _B]):
+    def __init__(
+        self, _fn: Callable[Concatenate[AsyncIterator[_A], _P], Coroutine[object, object, _B]]
+    ) -> None:
+        self._fn = _fn
 
-    def _outer(*__args: _P.args, **__kwargs: _P.kwargs) -> Sink[_A, _B]:
+    def __call__(self, *__args: _P.args, **__kwargs: _P.kwargs) -> Sink[_A, _B]:
+        @wraps(self._fn)
         async def _inner(src: AsyncIterator[_A]) -> AsyncIterator[_B]:
-            yield await _fn(src, *__args, **__kwargs)
+            yield await self._fn(src, *__args, **__kwargs)
 
         return Sink(_inner)
 
-    setattr(_outer, "_is_transformer_fn", True)
-    return wraps(_fn)(_outer)
+
+sink = _SinkFnWrapper
+
+# def sink(
+#     _fn: Callable[Concatenate[AsyncIterator[_A], _P], Coroutine[object, object, _B]]
+# ) -> Callable[_P, Sink[_A, _B]]:
+#     print(f"sink {_fn=}")
+#
+#     def _outer(*__args: _P.args, **__kwargs: _P.kwargs) -> Sink[_A, _B]:
+#         async def _inner(src: AsyncIterator[_A]) -> AsyncIterator[_B]:
+#             yield await _fn(src, *__args, **__kwargs)
+#
+#         return Sink(_inner)
+#
+#     setattr(_outer, "_is_transformer_fn", True)
+#     return wraps(_fn)(_outer)
 
 
 def transformer(
@@ -592,15 +603,16 @@ def stream(
     return _outer
 
 
-__all__ = [
+__all__ = (
+    "Filter",
+    "FlatMap",
+    "FnTransformer",
+    "Map",
+    "sink",
+    "Sink",
+    "stream",
     "Stream",
     "Transformer",
-    "Map",
-    "FlatMap",
-    "Filter",
-    "TransformerPipeline",
-    "FnTransformer",
     "transformer",
-    "stream",
-    "sink",
-]
+    "TransformerPipeline",
+)
