@@ -6,8 +6,6 @@ import time
 from asyncio import Future
 from typing import *
 
-from .sentinel import _RaiseExceptionT, Sentinel
-
 _T = TypeVar("_T")
 _U = TypeVar("_U")
 _R = TypeVar("_R")
@@ -175,60 +173,10 @@ def create_future() -> Future[_T]:
     return asyncio.get_running_loop().create_future()
 
 
-@overload
-def run_stream(
-    stream: AsyncIterable[_T],
-    if_empty: _RaiseExceptionT = Sentinel.RaiseException,
-) -> _T:
-    ...
-
-
-@overload
-def run_stream(
-    stream: AsyncIterable[_T],
-    if_empty: _U = ...,
-) -> _T | _U:
-    ...
-
-
-def run_stream(
-    stream: AsyncIterable[_T],
-    if_empty: _U | _RaiseExceptionT = Sentinel.RaiseException,
-) -> _T | _U:
-    """Run an async iterable to completion.
-
-    Args:
-        stream: The async iterable to run.
-        if_empty: The value to return if the stream is empty. Defaults to raising an exception.
-
-    Returns:
-        The last item yielded by the async iterable.
-
-    Raises:
-        ValueError: If the async iterable yields no items.
-
-    Examples:
-        >>> from astream.stream_utils import arange
-        >>> print(run_stream(arange(5) / (lambda x: x * 5)))
-    """
-
-    async def _runner(_stream: AsyncIterable[_T]) -> _T | _U:
-        item: _T | _U | _RaiseExceptionT = if_empty
-        async for item in _stream:
-            pass
-
-        if item is Sentinel.RaiseException:
-            raise ValueError("stream yielded no items")
-
-        return item
-
-    return asyncio.run(_runner(stream))
-
-
 __all__ = (
-    "run_sync",
-    "iter_to_aiter",
-    "ensure_coroutine_function",
-    "ensure_async_iterator",
     "create_future",
+    "ensure_async_iterator",
+    "ensure_coroutine_function",
+    "iter_to_aiter",
+    "run_sync",
 )
